@@ -20,6 +20,8 @@ is_builtin_style <- function(x) {
   x %in% names(builtin_styles)
 }
 
+#' @importFrom grDevices colors
+
 is_r_color <- function(x) {
   x %in% colors() || grepl(hash_color_regex, x)
 }
@@ -28,6 +30,8 @@ is_rgb_matrix <- function(x) {
   is.matrix(x) && is.numeric(x) && (nrow(x) == 3 || nrow(x) == 4)
 }
 
+#' @importFrom grDevices col2rgb
+
 style_from_r_color <- function(color, bg, num_colors, grey) {
   style_from_rgb(col2rgb(color), bg, num_colors, grey)
 }
@@ -305,6 +309,10 @@ sapply(names(builtin_styles), function(style) {
   assign(style, make_style(style), envir = asNamespace(packageName()))
 })
 
+.onLoad <- function(libname, pkgname) {
+  num_colors(forget = TRUE)
+}
+
 .onAttach <- function(libname, pkgname) {
   ub <- unlockBinding
   ub("my_styles", asNamespace(pkgname))
